# Table of Contents

- [data-quality-insights](<./data-quality-insights.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Data Quality Insights](<./Data-Quality-Insights.md>)
  - [Overview](<./Data-Quality-Insights/Overview.md>)
  - [Limitations](<./Data-Quality-Insights/Limitations.md>)
  - [Acting on Data Quality Issues](<./Data-Quality-Insights/Acting-on-Data-Quality-Issues.md>)
  - [Activating Data Quality Insights](<./Data-Quality-Insights/Activating-Data-Quality-Insights.md>)
  - [Was this page helpful?](<./Data-Quality-Insights/Was-this-page-helpful.md>)
